function [km,mm]=mr(x,A,I,E,R)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 	Calculate the elemental mass and stiffness matrices for an   %
%	element that is moment resisting.			     % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%       Richard Christenson		Last Modified: 10/97


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Find the length and orientation of the element.		     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
l=sqrt((x(1,2)-x(1,1))^2+(x(2,2)-x(2,1))^2);
T=diag(ones(6,1));
c=(x(1,2)-x(1,1))/l;
s=(x(2,2)-x(2,1))/l;
a=[1;2];
b=a+3;
T(a,a)=[c  s;-s c];
T(b,b)=[c  s;-s c];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Determine the member stiffness.				     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

g=A/I;
k1=[g;0;0;-g;0;0];
k2=[0;12/l/l;6/l;0;-12/l/l;6/l];
k3=[0;6/l;4;0;-6/l;2];
k6=[0;6/l;2;0;-6/l;4];
khat=(E*I/l)*[k1 k2 k3 -k1 -k2 k6];
km=T'*khat*T;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	Determine the member mass.				     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

mhat=zeros(6);
m1=R*A*l/6*[2 1; 1 2];
m2=R*A*l/420*[156 22*l 54 -13*l;22*l 4*l*l 13*l -3*l*l;54 13*l 156 -22*l;-13*l -3*l*l -22*l 4*l*l];
mhat([1 4],[1 4])=m1;
mhat([2 3 5 6],[2 3 5 6])=m2;
mm=T'*mhat*T;
