function sim_inp(pre,Tmax)
%
%	This program loads the data and defines any additional variables
%	to run the benchmark simulation with the sample controller.
%	PRE=1 sets up a pre-earthquake simulation, and PRE=0 sets up
%	a post-earthquake simulation. 
%
%	Each control designer may modify this program to run with
%	his/her control system. 
%
%	Shirley J. Dyke			Last Modified: 2/3/98

if (nargin<1), pre=1; end;

% SET SIMULATION STOP TIME (depends on earthquake and control system)
if (nargin<2), Tmax=100; end;

% LOAD PRE- or POST-EARTHQUAKE EVALUATION MODEL
% (Arpre / Arpost ---> redefine as Aeval for evaluation)
if (pre),
   load pre_mod 
   Aeval = Arpre;Beval = Brpre;Ceval = Crpre;Deval = Drpre;
else,
   load post_mod
   Aeval = Arpost;Beval = Brpost;Ceval = Crpost;Deval = Drpost;
end
outsize = length(Ceval(:,1));

% LOAD ACTUATOR MODEL (Adev Bdev Cdev Ddev Of ndev_flr flr ndev nflr ctrlsize)
evalin('base','load smpl_dev');

% LOAD CONTROL ALGORITHM (Acd Bcd Ccd Dcd Tcd Of) 
evalin('base','load smpl_ctl');

% LOAD SENSOR MODEL (snsr)
evalin('base','load smpl_snr');

% SET SIMULATION PARAMETERS (these must remain unchanged)
dtint   = 0.0005;		% Integration Time Step
dec	= 10;			% Decimation Step
qint 	= 20/(2^12);		% Quantizer Interval (+/-10V, 12 bit)
satlvl	= 10;			% Saturation Level of AD and DA Converters
nspow	= 0.03/1000;		% White Noise Power
nsdt	= 0.001;		% White Noise Sample Time

% FIND SUFFICIENT WHITE NOISE SEEDS
numv	= length(Om);
vseed	= zeros(numv,1);
randn('seed',123);
for i=1:numv,
   vseed(i)    = randn('seed');
   x           = randn(30000,1);
end

% SEND VARIABLES TO BASE WORKSPACE
assignin('base','Aeval',Aeval);
assignin('base','Beval',Beval);
assignin('base','Ceval',Ceval);
assignin('base','Deval',Deval);
assignin('base','Oe',Oe);
assignin('base','Om',Om);
assignin('base','Oc',Oc);
assignin('base','outsize',outsize);
assignin('base','dtint',dtint);
assignin('base','dec',dec);
assignin('base','qint',qint);
assignin('base','satlvl',satlvl);
assignin('base','nspow',nspow);
assignin('base','nsdt',nsdt);
assignin('base','Tmax',Tmax);
assignin('base','vseed',vseed);

% OPEN SIMULINK SIMULATION
eval_sim

%   FROM HERE THE SIMULATION CAN BE RUN FROM THE 'START'
%   BUTTON IN THE SIMULATION WINDOW, OR FROM THE COMMAND
%   LINE USING THE 'SIM' COMMAND (AS IN 'RUN_SIM.M').
