% SMPL_IO.M	
%
%	This program must be run before FORM_SS, and defines
%	the INP and OUT matrices used in the example control design. 
%
%	Each control designer should modify this program as 
%	needed to define the proper INP and OUT matrices for 
%	his/her control system. 
%
%	Shirley Dyke		Last Modified: 1/23/98

% LIST OF VARIABLES:
%  inp	= array defining location & direction of control forces 
%  out 	= array defining responses of state space models used for
%		evaluation, measurement, or connection


% CONTROL FORCE INPUTS
%  The INP matrix defines the location and components of each 
%  control force applied to the structure. The size of the INP matrix 
%  is (5 x the number of independent control forces).
%  
%  ROW	DESCRIPTION
%  1	Defines the number of each control force - and corresponds 
%	to the position of the force in the global force vector. 
%  2	Node at which the force is applied to the structure.
%  3	Horizontal component of the force applied to the structure. 
%  4	Vertical component of the force applied to the structure.
%  5	Rotational component of the force applied to the structure. 

temp1 = [1:20;1:20];
temp2a = [22 34 40 46 58 64 70 82 88 94 106 112 118 130 136 142 154 160 172 178];
temp2b = [15 temp2a(1:19)-1];
temp2 = [temp2b;temp2a];
temp3 = [-ones(1,20);ones(1,20)];

inp(1,:)=temp1(:)';	
inp(2,:)=temp2(:)';
inp(3,:)=temp3(:)';
inp(4,:)=[zeros(size(inp(3,:)))];
inp(5,:)=[zeros(size(inp(3,:)))];



% SYSTEM OUTPUT RESPONSES
%  The OUT matrix defines the node and components of each 
%  response. The size of the OUT matrix is (6 x the number of 
%  responses output).
% 
%  ROW	DESCRIPTION
%  1	Node number of response.
%  2	Degree of freedom desired (1=horizontal 2=vertical 3=rotational).
%  3	Order of derivative (0=displacement 1=velocity 2=acceleration).
%  4	Indicates if the output is a connection output (1=yes 0=no).
%  5	Indicates if the output is a measured output (1=yes 0=no).
%  6	Indicates if the output is an evaluation output (1=yes 0=no).

flrnds = [21 33 39 45 57 63 69 81 87 93 105 111 117 129 135 141 153 159 171 177];
nouts  = length(flrnds);

out(1,:) = [flrnds flrnds flrnds];
out(2,:) = [ones(1,3*nouts)];
out(3,:) = [zeros(1,nouts) ones(1,nouts) 2*ones(1,nouts)];
out(4,:) = [ones(1,2*nouts) zeros(1,nouts)];
out(5,:) = [zeros(1,3*nouts)];out(5,[44:4:60]) = 1;
out(6,:) = [ones(1,3*nouts)];


% CLEAR UNNECESSARY VARIABLES
clear temp1 temp2 temp3 temp2a temp2b nouts flrnds
